<CsoundSynthesizer>
<CsOptions>
-odac -d
</CsOptions>
<CsInstruments>

/*
 * M. Graziani
 * Example Orch
 *
*/
;============================================================
  sr        =	44100
  kr        =	4410
  ksmps     =	10
  nchnls    =	1
  0dbfs		=	32767

;============================================================
; Globals

  gisr2     = 	sr/2


; ********************************************************************
; ********************************************************************
/*
 * Instr 1
 * Oscillatore con inviluppo transeg
 */

;p1 = numero strumento
;p2 = istante di inizio della nota
;p3 = durata della nota
;p4 = ampiezza assoluta (0 - 32767 per 16 bit)
;p5 = frequenza: >0 in hz, <0 in midi
;p6 = numero funzione audio
;p7 = tempo d'attacco
;p8 = tempo di decadimento
;p9 = tipo transeg att
;p10 = tipo transeg dec
;p11 = fase oscil: se <0 casuale

	instr 1

; freq >0 hz; <0 midi
if (p5 > 0) then
	ifreq     =  p5
else      
	ifreq     =  cpsmidinn(-p5)
endif

idec	=	p8

; attack: se < 0 % durata
if  (p7 < 0) then
  iatt      =  abs(p7)*p3/100                    ; value in % p3
            else      
  iatt      =  p7                                ; value in sec
endif

; decay: se = 0 durata - attacco
if (idec == 0) then
	idec	=	p3-iatt
endif

; fase oscil: se <0 casuale
if (p11 < 0) then
	iphase	=	rnd(-p11)
else
	iphase	=	p11
endif

kenv	transeg	0, iatt, p9, p4, p3-iatt-idec, 0, p4, idec, p10, 0
asig	oscili	kenv, ifreq, p6, iphase

		out		asig

/*
 * fase     diff in samples   freq ampiezza doppia    freq cancellata (e suoi arm dispari)
 * iphase, (sr/ifreq)*iphase, sr/((sr/ifreq)*iphase), (sr/((sr/ifreq)*iphase))/2
 * di conseguenza
 * freq_canc = (sr/((sr/ifreq)*iphase))/2
 * freq_canc * 2 = sr/((sr/ifreq)*iphase)
 * freq_canc * 2 * (sr/ifreq)*iphase = sr
 * iphase = sr / (freq_canc * 2 * (sr/ifreq))
*/

if (iphase > 0) then
	print	iphase, (sr/ifreq)*iphase, sr/((sr/ifreq)*iphase), (sr/((sr/ifreq)*iphase))/2
endif
	endin
; ********************************************************************
/*
 * Instr 3
 * Oscillatore con inviluppo lineare
 * random su frequenza e ampiezza
 */

;p1 = numero strumento
;p2 = istante di inizio della nota
;p3 = durata della nota
;p4 = ampiezza assoluta (0 - 32767 per 16 bit)
;p5 = frequenza: >0 in hz, <0 in midi
;p6 = numero funzione audio
;p7 = tempo d'attacco
;p8 = tempo di decadimento
;p9 = tipo transeg att
;p10 = tipo transeg dec
;p11 = int(p11) = random freq rate; frac(p11) = random freq range %
;p12 = int(p12) = random amp freq; frac(p12) = random amp range %

	instr 3

; freq >0 hz; <0 midi
if (p5 > 0) then
	ifreq     =  p5
else      
	ifreq     =  cpsmidinn(-p5)
endif

idec	=	p8

; attack: se < 0 % durata
if  (p7 < 0) then
  iatt      =  abs(p7)*p3/100                    ; value in % p3
            else      
  iatt      =  p7                                ; value in sec
endif

; decay: se = 0 durata - attacco
if (idec == 0) then
	idec	=	p3-iatt
endif

; random freq deviation
ifdev	=		ifreq*frac(p11)
krand	randi	ifdev, int(p11), 2

kenv	transeg	0, iatt, p9, p4, p3-iatt-idec, 0, p4, idec, p10, 0

; random amp deviation
kramp	randi	kenv*frac(p12), int(p12), 2

asig	oscili	kenv + kramp, ifreq + krand, p6, 0

		out		asig

		print	ifdev
	endin

;============================================================
; instr 40
; drnoi: double resonated noise
;============================================================

; NEED F 98,99 (size 8192) FOR AMPLITUDE COMPENSATION; ex:
; f 98  0     8193  -27   0     60    3     30.66 6     23.58 12    14.82 24    8.47  48    6.55  95    4.38  190   3.06  380   2.28  761   1.6797      1522  1.6779      3043  2.4956      6087  7.259 8192  7.66
; f 99  0     8193  -27   0     5000  2     1500  3     833   4     770   5     666   6     417   7     350   8     50    16    70    25    50    33    35    41    17    49    12    57    16    66    14    74    8     82    11    164   7     246   6.3   328   4.1   410   4.3   492   3.56  573   3.25  655   2.73  737   2.48  819   2.41  1638  1.88  2458  1.52  3277  1.28  4096  1.104 4915  1.054 5734  .996  6554  .9422 7373  .8873 8192  .8653


; p4    amp
; p5    base freq >= 20 hz, < 20 oct
; p6    bandwidth factor: bw = freq*p6 - standard .02
; p7   signal  attack > 0 sec, < 0 %
; p8           decay > 0 sec, < 0 %
; p9           sustain level [0-1]
; p10           release > 0 sec, < 0 %  
; p11           env type 0 straight, > 0 exp, < 0 log

    instr   40

; ifreq is the main frequency
if (p5 >= 20) then
  ifreq     =  p5
else      
  ifreq     =  cpsoct(p5)
 endif

; average factor between 2 reson's central freq = .9987
; max 1.0074 - min .99

;   ifreq2    =  ifreq * 1.00575
retry:
  ifreq2    random    .99, 1.01
if (abs(1 - ifreq2) < .005) igoto retry
  ifreq2    =  ifreq * ifreq2

; fixed bandwidth = ifreq * factor
  ibw       =  ifreq * p6

  iseed     =  rnd(1)

; amplitudes init
  iafact1   tablei    ifreq/gisr2, 98, 1          ; amp compensation by freq
  iafact2   tablei    p6*8192, 99, 0              ; bw compensation
  iafact    =  iafact1 * iafact2

if (p4 <= 0) then                                 ; amp in db 0 -inf
  iamp      =  ampdbfs(p4)
else
  iamp      =  p4
endif

; amp compensation for fletcher effect
if (ifreq < 300) then
  iamp      =  iamp * (300 / ifreq)
endif
  iamp      =  iamp * iafact

; init envelopes
  ishortatt =  0.001                              ; shortest time value for attack
  ishortdec =  0.01                               ; shortest time value for decay
  ishortrel =  0.1                                ; shortest time value for release

; signal sustain p9
  isus      =  p9 * iamp

; signal attack p7
if (p7 == 0) then                                ; default
  iatt      =  ishortatt
elseif  (p7 < 0) then                            ; value in % p3
  iatt      =  abs(p7)*p3/100
            else      
  iatt      =  p7                                ; value in sec
endif

; signal decay p8
if      (p8 == 0) then                           ; default
  idec      =  p3-iatt
  isus      =  0
elseif  (p8 < 0) then                            ; value in % p3
  idec      =  abs(p8)*p3/100
            else      
  idec      =  p8                                ; value in sec
endif

; signal release p10
if      (p10 == 0) then                           ; default
  irel      =  p3-iatt-idec
elseif  (p10 < 0) then                            ; value in % p3
  irel      =  abs(p10)*p3/100
            else      
  irel      =  p10                                ; value in sec
endif

; signal type p11
  itype     =  p11

; envelope
  kenv      transeg   0, iatt, itype, iamp, idec, -itype, isus, p3-iatt-idec-irel, itype, isus, irel, -itype, 0


; signal
  anoise    randi     1.0, 13000, iseed
  ares      reson     anoise, ifreq, ibw, 1
  ares1     reson     ares, ifreq2, ibw, 1
  asig      =         ares1 * kenv
            out       asig

            print     p2, p3, ifreq, ifreq2, ibw, iafact, iamp, iafact1, iafact2, iatt, idec, irel
;           prints    "%8.4f\\n", p6
endin

;============================================================
; instr 41
; drnoi: double resonated noise
; like 40 but balance for amp compensation
;============================================================


; p4    amp
; p5    base freq >= 20 hz, < 20 oct
; p6    bandwidth factor: bw = freq*p6 - standard .02
; p7   signal  attack > 0 sec, < 0 %
; p8           decay > 0 sec, < 0 %
; p9           sustain level [0-1]
; p10           release > 0 sec, < 0 %  
; p11           env type 0 straight, > 0 exp, < 0 log

    instr   41

; ifreq is the main frequency
if (p5 >= 20) then
  ifreq     =  p5
else      
  ifreq     =  cpsoct(p5)
 endif

; average factor between 2 reson's central freq = .9987
; max 1.0074 - min .99

;   ifreq2    =  ifreq * 1.00575
retry:
  ifreq2    random    .99, 1.01
if (abs(1 - ifreq2) < .005) igoto retry
  ifreq2    =  ifreq * ifreq2

; fixed bandwidth = ifreq * factor
  ibw       =  ifreq * p6

  iseed     =  rnd(1)

if (p4 <= 0) then                                 ; amp in db 0 -inf
  iamp      =  ampdbfs(p4)
else
  iamp      =  p4
endif

; amp compensation for fletcher effect
if (ifreq < 300) then
  iamp      =  iamp * (300 / ifreq)
endif

; init envelopes
  ishortatt =  0.001                              ; shortest time value for attack
  ishortdec =  0.01                               ; shortest time value for decay
  ishortrel =  0.1                                ; shortest time value for release

; signal sustain p9
  isus      =  p9 * iamp

; signal attack p7
if (p7 == 0) then                                ; default
  iatt      =  ishortatt
elseif  (p7 < 0) then                            ; value in % p3
  iatt      =  abs(p7)*p3/100
            else      
  iatt      =  p7                                ; value in sec
endif

; signal decay p8
if      (p8 == 0) then                           ; default
  idec      =  p3-iatt
  isus      =  0
elseif  (p8 < 0) then                            ; value in % p3
  idec      =  abs(p8)*p3/100
            else      
  idec      =  p8                                ; value in sec
endif

; signal release p10
if      (p10 == 0) then                           ; default
  irel      =  p3-iatt-idec
elseif  (p10 < 0) then                            ; value in % p3
  irel      =  abs(p10)*p3/100
            else      
  irel      =  p10                                ; value in sec
endif

; signal type p11
  itype     =  p11

; envelope
  kenv      transeg   0, iatt, itype, iamp, idec, -itype, isus, p3-iatt-idec-irel, itype, isus, irel, -itype, 0


; signal
  anoise    randi     1.0, 13000, iseed
  ares      reson     anoise, ifreq, ibw, 1
  ares1     reson     ares, ifreq2, ibw, 1
  asig      =         ares1 * kenv
  abal      balance   asig, anoise * kenv
            out       abal

            print     p2, ifreq, ifreq2, iamp

endin

;============================================================
; instr 42
; sin with randi amp mod
;============================================================


; p4    amp
; p5    base freq >= 20 hz, < 20 oct
; p6    bandwidth factor: bw = freq*p6 - standard .02
; p7   signal  attack > 0 sec, < 0 %
; p8           decay > 0 sec, < 0 %
; p9           sustain level [0-1]
; p10           release > 0 sec, < 0 %  
; p11           env type 0 straight, > 0 exp, < 0 log

    instr   42

; ifreq is the main frequency
if (p5 >= 20) then
  ifreq     =  p5
else      
  ifreq     =  cpsoct(p5)
 endif

; fixed bandwidth = ifreq * factor
  ibw       =  ifreq * p6

  iseed     =  rnd(1)

if (p4 <= 0) then                                 ; amp in db 0 -inf
  iamp      =  ampdbfs(p4)
else
  iamp      =  p4
endif

; amp compensation for fletcher effect
if (ifreq < 300) then
  iamp      =  iamp * (300 / ifreq)
endif

; init envelopes
  ishortatt =  0.001                              ; shortest time value for attack
  ishortdec =  0.01                               ; shortest time value for decay
  ishortrel =  0.1                                ; shortest time value for release

; signal sustain p9
  isus      =  p9 * iamp

; signal attack p7
if (p7 == 0) then                                ; default
  iatt      =  ishortatt
elseif  (p7 < 0) then                            ; value in % p3
  iatt      =  abs(p7)*p3/100
            else      
  iatt      =  p7                                ; value in sec
endif

; signal decay p8
if      (p8 == 0) then                           ; default
  idec      =  p3-iatt
  isus      =  0
elseif  (p8 < 0) then                            ; value in % p3
  idec      =  abs(p8)*p3/100
            else      
  idec      =  p8                                ; value in sec
endif

; signal release p10
if      (p10 == 0) then                           ; default
  irel      =  p3-iatt-idec
elseif  (p10 < 0) then                            ; value in % p3
  irel      =  abs(p10)*p3/100
            else      
  irel      =  p10                                ; value in sec
endif

; signal type p11
  itype     =  p11

; envelope
  kenv      transeg   0, iatt, itype, iamp, idec, -itype, isus, p3-iatt-idec-irel, itype, isus, irel, -itype, 0


; signal
  anoise    randi     1.0, ibw, iseed
  asin      oscili    1.0, ifreq, 1
  asig      =         anoise * asin
            out       asig * kenv

            print     p2, ifreq, iamp

endin



</CsInstruments>
<CsScore>
; START EVENT: at 0.0000 - dur 1.0000 - end 1.0000 - stop_type 0 - den_type 0
; =============================================================================================
; Tabelle create come somma di armonici consecutivi con la GEN 10
; f 1 sinusoide
f 1 0 16384 10    1
; =============================================================================================
; functions to rescale amplitude in drnoi type instrument 40
f 98  0     8193  -27   0     60    3     30.66 6     23.58 12    14.82 24    8.47  48    6.55  95    4.38  190   3.06  380   2.28  761   1.6797      1522  1.6779      3043  2.4956      6087  7.259 8192  7.66
f 99  0     8193  -27   0     5000  2     1500  3     833   4     770   5     666   6     417   7     350   8     50    16    70    25    50    33    35    41    17    49    12    57    16    66    14    74    8     82    11    164   7     246   6.3   328   4.1   410   4.3   492   3.56  573   3.25  655   2.73  737   2.48  819   2.41  1638  1.88  2458  1.52  3277  1.28  4096  1.104 4915  1.054 5734  .996  6554  .9422 7373  .8873 8192  .8653

; avanza
;a 0 0 175

; ***********************************************************************************************
; large chords
; mercurio
; START EVENT: at 0.0000 - notes# 8 - stop_type 2 - den_type 0
i01     0.0000    20.0000  3000.0000    97.9933     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01     0.0000    13.0000  2000.0000   171.4883     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01     0.0000    10.0000  2000.0000   244.9833     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01     0.0000     7.0000  1200.0000   367.4750     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01     0.0001    14.0000   700.0000  1273.9133     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01     0.0001    10.0000   500.0000  2327.3416     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01     0.0001    17.0000   300.0000  4801.6732     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01     0.0001    20.0000   200.0000  7349.4998     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
; END EVENT: generated 8 - direct 0

; venere
; START EVENT: at 10.0000 - notes# 8 - stop_type 2 - den_type 0
i01    10.0000    20.0000  3000.0000    55.9962     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    10.0000    13.0000  2000.0000    97.9933     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    10.0000    10.0000  2000.0000   139.9905     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    10.0000     7.0000  1200.0000   209.9857     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    10.0000    14.0000   700.0000   727.9505     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    10.0001    10.0000   500.0000  1329.9095     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    10.0001    17.0000   300.0000  2743.8133     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    10.0001    20.0000   200.0000  4199.7142     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
; END EVENT: generated 8 - direct 0

; terra
; START EVENT: at 20.0000 - notes# 8 - stop_type 2 - den_type 0
i01    20.0000    20.0000  3000.0000    78.3950     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    20.0000    13.0000  2000.0000   137.1910     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    20.0000    10.0000  2000.0000    97.9933     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    20.0000     7.0000  1200.0000   146.9900     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    20.0001    14.0000   700.0000   509.5653     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    20.0001    10.0000   500.0000   930.9366     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    20.0001    17.0000   300.0000  1920.6693     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    20.0001    20.0000   200.0000  2939.7999     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
; END EVENT: generated 8 - direct 0

; marte
; START EVENT: at 30.0000 - notes# 8 - stop_type 2 - den_type 0
i01    30.0000    16.0000  4000.0000   261.3160     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    30.1600    10.0000  2800.0000   391.9730     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    30.2600     8.0000  1960.0000    91.4600     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    30.3400     5.0000  1372.0000   209.0520     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    30.3900    11.0000   960.4000  1241.2490     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    30.5000     8.0000   672.2800  2717.6820     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    30.5800    12.0000   470.5960  3919.7330     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    30.7000    16.0000   329.4172 10243.5700     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
; END EVENT: generated 8 - direct 0

; giove
; START EVENT: at 38.0000 - notes# 8 - stop_type 2 - den_type 0
i01    38.0000    20.0000  4000.0000   301.5180     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    38.4000    13.0000  2800.0000  1567.8900     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    38.6600    10.0000  1960.0000   211.0630     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    38.8600     7.0000  1372.0000   120.6070     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    39.0000     9.0000   960.4000   452.2770     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    39.1800    10.0000   672.2800  9045.5400     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    39.3800    17.0000   470.5960  5909.7500     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    39.7200    20.0000   329.4172  2864.4200     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
; END EVENT: generated 8 - direct 0

; saturno
; START EVENT: at 48.0000 - notes# 8 - stop_type 2 - den_type 0
i01    48.0000    20.0000  4000.0000   247.5620     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    48.6667    13.0000  2800.0000   231.0580     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    49.1000    10.0000  1960.0000   495.1240     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    49.4333     7.0000  1372.0000   330.0830     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    49.6667     9.0000   960.4000  1716.4300     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    49.9667    10.0000   672.2800  3135.7800     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    50.3000    17.0000   470.5960  6469.6200     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    50.8667    20.0000   329.4172  4951.2400     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
; END EVENT: generated 8 - direct 0

; urano
; START EVENT: at 55.0000 - notes# 8 - stop_type 2 - den_type 0
i01    55.0000    20.0000  4000.0000   831.9430     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    56.0000    13.0000  2800.0000   239.9840     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    56.6500    10.0000  1960.0000  3039.7900     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    57.1500     7.0000  1372.0000   479.9670     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    57.5000     9.0000   960.4000   319.9780     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    57.9500    10.0000   672.2800   223.9850     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    58.4500    17.0000   470.5960  6271.5700     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    59.3000    20.0000   329.4172  2399.8300     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
; END EVENT: generated 8 - direct 0

; nettuno
; START EVENT: at 60.0000 - notes# 8 - stop_type 2 - den_type 0
i01    60.0000    20.0000  4000.0000   543.5360     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    62.0000    13.0000  2800.0000   209.0520     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    63.3000    10.0000  1960.0000   146.3370     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    64.3000     7.0000  1372.0000    83.6210     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    65.0000     9.0000   960.4000   992.9990     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    65.9000    10.0000   672.2800  4097.4300     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    66.9000    17.0000   470.5960  1985.9900     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
i01    68.6000    20.0000   329.4172  1087.0730     1   -50.0000     0.0000     1.0000     -1.0000     0.0000
; END EVENT: generated 8 - direct 0

; ---------------------- END FILE: total 84
s

; ***********************************************************************************************
; large chords
; mercurio
; START EVENT: at 0.0000 - notes# 8 - stop_type 2 - den_type 0
i03     0.0000    20.0000  3000.0000    97.9933     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03     0.0000    13.0000  2000.0000   171.4883     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03     0.0000    10.0000  2000.0000   244.9833     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03     0.0000     7.0000  1200.0000   367.4750     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03     0.0001    14.0000   700.0000  1273.9133     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03     0.0001    10.0000   500.0000  2327.3416     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03     0.0001    17.0000   300.0000  4801.6732     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03     0.0001    20.0000   200.0000  7349.4998     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
; END EVENT: generated 8 - direct 0

; venere
; START EVENT: at 10.0000 - notes# 8 - stop_type 2 - den_type 0
i03    10.0000    20.0000  3000.0000    55.9962     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    10.0000    13.0000  2000.0000    97.9933     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    10.0000    10.0000  2000.0000   139.9905     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    10.0000     7.0000  1200.0000   209.9857     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    10.0000    14.0000   700.0000   727.9505     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    10.0001    10.0000   500.0000  1329.9095     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    10.0001    17.0000   300.0000  2743.8133     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    10.0001    20.0000   200.0000  4199.7142     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
; END EVENT: generated 8 - direct 0

; terra
; START EVENT: at 20.0000 - notes# 8 - stop_type 2 - den_type 0
i03    20.0000    20.0000  3000.0000    78.3950     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    20.0000    13.0000  2000.0000   137.1910     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    20.0000    10.0000  2000.0000    97.9933     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    20.0000     7.0000  1200.0000   146.9900     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    20.0001    14.0000   700.0000   509.5653     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    20.0001    10.0000   500.0000   930.9366     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    20.0001    17.0000   300.0000  1920.6693     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    20.0001    20.0000   200.0000  2939.7999     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
; END EVENT: generated 8 - direct 0

; marte
; START EVENT: at 30.0000 - notes# 8 - stop_type 2 - den_type 0
i03    30.0000    16.0000  4000.0000   261.3160     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    30.1600    10.0000  2800.0000   391.9730     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    30.2600     8.0000  1960.0000    91.4600     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    30.3400     5.0000  1372.0000   209.0520     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    30.3900    11.0000   960.4000  1241.2490     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    30.5000     8.0000   672.2800  2717.6820     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    30.5800    12.0000   470.5960  3919.7330     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    30.7000    16.0000   329.4172 10243.5700     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
; END EVENT: generated 8 - direct 0

; giove
; START EVENT: at 38.0000 - notes# 8 - stop_type 2 - den_type 0
i03    38.0000    20.0000  4000.0000   301.5180     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    38.4000    13.0000  2800.0000  1567.8900     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    38.6600    10.0000  1960.0000   211.0630     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    38.8600     7.0000  1372.0000   120.6070     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    39.0000     9.0000   960.4000   452.2770     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    39.1800    10.0000   672.2800  9045.5400     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    39.3800    17.0000   470.5960  5909.7500     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    39.7200    20.0000   329.4172  2864.4200     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
; END EVENT: generated 8 - direct 0

; saturno
; START EVENT: at 48.0000 - notes# 8 - stop_type 2 - den_type 0
i03    48.0000    20.0000  4000.0000   247.5620     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    48.6667    13.0000  2800.0000   231.0580     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    49.1000    10.0000  1960.0000   495.1240     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    49.4333     7.0000  1372.0000   330.0830     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    49.6667     9.0000   960.4000  1716.4300     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    49.9667    10.0000   672.2800  3135.7800     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    50.3000    17.0000   470.5960  6469.6200     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    50.8667    20.0000   329.4172  4951.2400     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
; END EVENT: generated 8 - direct 0

; urano
; START EVENT: at 55.0000 - notes# 8 - stop_type 2 - den_type 0
i03    55.0000    20.0000  4000.0000   831.9430     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    56.0000    13.0000  2800.0000   239.9840     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    56.6500    10.0000  1960.0000  3039.7900     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    57.1500     7.0000  1372.0000   479.9670     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    57.5000     9.0000   960.4000   319.9780     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    57.9500    10.0000   672.2800   223.9850     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    58.4500    17.0000   470.5960  6271.5700     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    59.3000    20.0000   329.4172  2399.8300     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
; END EVENT: generated 8 - direct 0

; nettuno
; START EVENT: at 60.0000 - notes# 8 - stop_type 2 - den_type 0
i03    60.0000    20.0000  4000.0000   543.5360     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    62.0000    13.0000  2800.0000   209.0520     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    63.3000    10.0000  1960.0000   146.3370     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    64.3000     7.0000  1372.0000    83.6210     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    65.0000     9.0000   960.4000   992.9990     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    65.9000    10.0000   672.2800  4097.4300     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    66.9000    17.0000   470.5960  1985.9900     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
i03    68.6000    20.0000   329.4172  1087.0730     1   -50.0000     0.0000     1.0000     -1.0000     3.005    2.05
; END EVENT: generated 8 - direct 0

; ---------------------- END FILE: total 84
s

; large chords
; mercurio
; START EVENT: at 0.0000 - notes# 8 - stop_type 2 - den_type 0
i42     0.0000    20.0000  3000.0000    97.9933     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42     0.0000    13.0000  2000.0000   171.4883     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42     0.0000    10.0000  2000.0000   244.9833     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42     0.0000     7.0000  1200.0000   367.4750     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42     0.0001    14.0000   700.0000  1273.9133     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42     0.0001    10.0000   500.0000  2327.3416     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42     0.0001    17.0000   300.0000  4801.6732     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42     0.0001    20.0000   200.0000  7349.4998     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; venere
; START EVENT: at 10.0000 - notes# 8 - stop_type 2 - den_type 0
i42    10.0000    20.0000  3000.0000    55.9962     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    10.0000    13.0000  2000.0000    97.9933     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    10.0000    10.0000  2000.0000   139.9905     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    10.0000     7.0000  1200.0000   209.9857     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    10.0000    14.0000   700.0000   727.9505     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    10.0001    10.0000   500.0000  1329.9095     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    10.0001    17.0000   300.0000  2743.8133     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    10.0001    20.0000   200.0000  4199.7142     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; terra
; START EVENT: at 20.0000 - notes# 8 - stop_type 2 - den_type 0
i42    20.0000    20.0000  3000.0000    78.3950     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    20.0000    13.0000  2000.0000   137.1910     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    20.0000    10.0000  2000.0000    97.9933     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    20.0000     7.0000  1200.0000   146.9900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    20.0001    14.0000   700.0000   509.5653     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    20.0001    10.0000   500.0000   930.9366     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    20.0001    17.0000   300.0000  1920.6693     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    20.0001    20.0000   200.0000  2939.7999     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; marte
; START EVENT: at 30.0000 - notes# 8 - stop_type 2 - den_type 0
i42    30.0000    16.0000  4000.0000   261.3160     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    30.1600    10.0000  2800.0000   391.9730     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    30.2600     8.0000  1960.0000    91.4600     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    30.3400     5.0000  1372.0000   209.0520     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    30.3900    11.0000   960.4000  1241.2490     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    30.5000     8.0000   672.2800  2717.6820     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    30.5800    12.0000   470.5960  3919.7330     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    30.7000    16.0000   329.4172 10243.5700     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; giove
; START EVENT: at 38.0000 - notes# 8 - stop_type 2 - den_type 0
i42    38.0000    20.0000  4000.0000   301.5180     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    38.4000    13.0000  2800.0000  1567.8900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    38.6600    10.0000  1960.0000   211.0630     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    38.8600     7.0000  1372.0000   120.6070     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    39.0000     9.0000   960.4000   452.2770     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    39.1800    10.0000   672.2800  9045.5400     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    39.3800    17.0000   470.5960  5909.7500     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    39.7200    20.0000   329.4172  2864.4200     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; saturno
; START EVENT: at 48.0000 - notes# 8 - stop_type 2 - den_type 0
i42    48.0000    20.0000  4000.0000   247.5620     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    48.6667    13.0000  2800.0000   231.0580     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    49.1000    10.0000  1960.0000   495.1240     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    49.4333     7.0000  1372.0000   330.0830     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    49.6667     9.0000   960.4000  1716.4300     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    49.9667    10.0000   672.2800  3135.7800     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    50.3000    17.0000   470.5960  6469.6200     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    50.8667    20.0000   329.4172  4951.2400     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; urano
; START EVENT: at 55.0000 - notes# 8 - stop_type 2 - den_type 0
i42    55.0000    20.0000  4000.0000   831.9430     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    56.0000    13.0000  2800.0000   239.9840     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    56.6500    10.0000  1960.0000  3039.7900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    57.1500     7.0000  1372.0000   479.9670     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    57.5000     9.0000   960.4000   319.9780     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    57.9500    10.0000   672.2800   223.9850     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    58.4500    17.0000   470.5960  6271.5700     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    59.3000    20.0000   329.4172  2399.8300     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; nettuno
; START EVENT: at 60.0000 - notes# 8 - stop_type 2 - den_type 0
i42    60.0000    20.0000  4000.0000   543.5360     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    62.0000    13.0000  2800.0000   209.0520     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    63.3000    10.0000  1960.0000   146.3370     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    64.3000     7.0000  1372.0000    83.6210     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    65.0000     9.0000   960.4000   992.9990     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    65.9000    10.0000   672.2800  4097.4300     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    66.9000    17.0000   470.5960  1985.9900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i42    68.6000    20.0000   329.4172  1087.0730     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; ---------------------- END FILE: total 84
s

; ***********************************************************************************************
; large chords
; mercurio
; START EVENT: at 0.0000 - notes# 8 - stop_type 2 - den_type 0
i40     0.0000    20.0000  3000.0000    97.9933     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40     0.0000    13.0000  2000.0000   171.4883     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40     0.0000    10.0000  2000.0000   244.9833     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40     0.0000     7.0000  1200.0000   367.4750     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40     0.0001    14.0000   700.0000  1273.9133     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40     0.0001    10.0000   500.0000  2327.3416     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40     0.0001    17.0000   300.0000  4801.6732     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40     0.0001    20.0000   200.0000  7349.4998     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; venere
; START EVENT: at 10.0000 - notes# 8 - stop_type 2 - den_type 0
i40    10.0000    20.0000  3000.0000    55.9962     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    10.0000    13.0000  2000.0000    97.9933     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    10.0000    10.0000  2000.0000   139.9905     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    10.0000     7.0000  1200.0000   209.9857     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    10.0000    14.0000   700.0000   727.9505     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    10.0001    10.0000   500.0000  1329.9095     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    10.0001    17.0000   300.0000  2743.8133     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    10.0001    20.0000   200.0000  4199.7142     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; terra
; START EVENT: at 20.0000 - notes# 8 - stop_type 2 - den_type 0
i40    20.0000    20.0000  3000.0000    78.3950     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    20.0000    13.0000  2000.0000   137.1910     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    20.0000    10.0000  2000.0000    97.9933     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    20.0000     7.0000  1200.0000   146.9900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    20.0001    14.0000   700.0000   509.5653     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    20.0001    10.0000   500.0000   930.9366     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    20.0001    17.0000   300.0000  1920.6693     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    20.0001    20.0000   200.0000  2939.7999     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; marte
; START EVENT: at 30.0000 - notes# 8 - stop_type 2 - den_type 0
i40    30.0000    16.0000  4000.0000   261.3160     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    30.1600    10.0000  2800.0000   391.9730     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    30.2600     8.0000  1960.0000    91.4600     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    30.3400     5.0000  1372.0000   209.0520     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    30.3900    11.0000   960.4000  1241.2490     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    30.5000     8.0000   672.2800  2717.6820     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    30.5800    12.0000   470.5960  3919.7330     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    30.7000    16.0000   329.4172 10243.5700     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; giove
; START EVENT: at 38.0000 - notes# 8 - stop_type 2 - den_type 0
i40    38.0000    20.0000  4000.0000   301.5180     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    38.4000    13.0000  2800.0000  1567.8900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    38.6600    10.0000  1960.0000   211.0630     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    38.8600     7.0000  1372.0000   120.6070     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    39.0000     9.0000   960.4000   452.2770     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    39.1800    10.0000   672.2800  9045.5400     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    39.3800    17.0000   470.5960  5909.7500     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    39.7200    20.0000   329.4172  2864.4200     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; saturno
; START EVENT: at 48.0000 - notes# 8 - stop_type 2 - den_type 0
i40    48.0000    20.0000  4000.0000   247.5620     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    48.6667    13.0000  2800.0000   231.0580     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    49.1000    10.0000  1960.0000   495.1240     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    49.4333     7.0000  1372.0000   330.0830     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    49.6667     9.0000   960.4000  1716.4300     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    49.9667    10.0000   672.2800  3135.7800     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    50.3000    17.0000   470.5960  6469.6200     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    50.8667    20.0000   329.4172  4951.2400     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; urano
; START EVENT: at 55.0000 - notes# 8 - stop_type 2 - den_type 0
i40    55.0000    20.0000  4000.0000   831.9430     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    56.0000    13.0000  2800.0000   239.9840     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    56.6500    10.0000  1960.0000  3039.7900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    57.1500     7.0000  1372.0000   479.9670     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    57.5000     9.0000   960.4000   319.9780     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    57.9500    10.0000   672.2800   223.9850     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    58.4500    17.0000   470.5960  6271.5700     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    59.3000    20.0000   329.4172  2399.8300     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; nettuno
; START EVENT: at 60.0000 - notes# 8 - stop_type 2 - den_type 0
i40    60.0000    20.0000  4000.0000   543.5360     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    62.0000    13.0000  2800.0000   209.0520     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    63.3000    10.0000  1960.0000   146.3370     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    64.3000     7.0000  1372.0000    83.6210     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    65.0000     9.0000   960.4000   992.9990     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    65.9000    10.0000   672.2800  4097.4300     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    66.9000    17.0000   470.5960  1985.9900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i40    68.6000    20.0000   329.4172  1087.0730     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; ---------------------- END FILE: total 84
s
; large chords
; mercurio
; START EVENT: at 0.0000 - notes# 8 - stop_type 2 - den_type 0
i41     0.0000    20.0000  3000.0000    97.9933     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41     0.0000    13.0000  2000.0000   171.4883     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41     0.0000    10.0000  2000.0000   244.9833     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41     0.0000     7.0000  1200.0000   367.4750     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41     0.0001    14.0000   700.0000  1273.9133     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41     0.0001    10.0000   500.0000  2327.3416     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41     0.0001    17.0000   300.0000  4801.6732     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41     0.0001    20.0000   200.0000  7349.4998     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; venere
; START EVENT: at 10.0000 - notes# 8 - stop_type 2 - den_type 0
i41    10.0000    20.0000  3000.0000    55.9962     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    10.0000    13.0000  2000.0000    97.9933     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    10.0000    10.0000  2000.0000   139.9905     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    10.0000     7.0000  1200.0000   209.9857     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    10.0000    14.0000   700.0000   727.9505     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    10.0001    10.0000   500.0000  1329.9095     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    10.0001    17.0000   300.0000  2743.8133     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    10.0001    20.0000   200.0000  4199.7142     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; terra
; START EVENT: at 20.0000 - notes# 8 - stop_type 2 - den_type 0
i41    20.0000    20.0000  3000.0000    78.3950     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    20.0000    13.0000  2000.0000   137.1910     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    20.0000    10.0000  2000.0000    97.9933     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    20.0000     7.0000  1200.0000   146.9900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    20.0001    14.0000   700.0000   509.5653     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    20.0001    10.0000   500.0000   930.9366     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    20.0001    17.0000   300.0000  1920.6693     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    20.0001    20.0000   200.0000  2939.7999     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; marte
; START EVENT: at 30.0000 - notes# 8 - stop_type 2 - den_type 0
i41    30.0000    16.0000  4000.0000   261.3160     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    30.1600    10.0000  2800.0000   391.9730     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    30.2600     8.0000  1960.0000    91.4600     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    30.3400     5.0000  1372.0000   209.0520     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    30.3900    11.0000   960.4000  1241.2490     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    30.5000     8.0000   672.2800  2717.6820     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    30.5800    12.0000   470.5960  3919.7330     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    30.7000    16.0000   329.4172 10243.5700     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; giove
; START EVENT: at 38.0000 - notes# 8 - stop_type 2 - den_type 0
i41    38.0000    20.0000  4000.0000   301.5180     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    38.4000    13.0000  2800.0000  1567.8900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    38.6600    10.0000  1960.0000   211.0630     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    38.8600     7.0000  1372.0000   120.6070     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    39.0000     9.0000   960.4000   452.2770     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    39.1800    10.0000   672.2800  9045.5400     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    39.3800    17.0000   470.5960  5909.7500     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    39.7200    20.0000   329.4172  2864.4200     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; saturno
; START EVENT: at 48.0000 - notes# 8 - stop_type 2 - den_type 0
i41    48.0000    20.0000  4000.0000   247.5620     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    48.6667    13.0000  2800.0000   231.0580     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    49.1000    10.0000  1960.0000   495.1240     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    49.4333     7.0000  1372.0000   330.0830     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    49.6667     9.0000   960.4000  1716.4300     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    49.9667    10.0000   672.2800  3135.7800     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    50.3000    17.0000   470.5960  6469.6200     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    50.8667    20.0000   329.4172  4951.2400     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; urano
; START EVENT: at 55.0000 - notes# 8 - stop_type 2 - den_type 0
i41    55.0000    20.0000  4000.0000   831.9430     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    56.0000    13.0000  2800.0000   239.9840     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    56.6500    10.0000  1960.0000  3039.7900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    57.1500     7.0000  1372.0000   479.9670     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    57.5000     9.0000   960.4000   319.9780     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    57.9500    10.0000   672.2800   223.9850     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    58.4500    17.0000   470.5960  6271.5700     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    59.3000    20.0000   329.4172  2399.8300     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; nettuno
; START EVENT: at 60.0000 - notes# 8 - stop_type 2 - den_type 0
i41    60.0000    20.0000  4000.0000   543.5360     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    62.0000    13.0000  2800.0000   209.0520     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    63.3000    10.0000  1960.0000   146.3370     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    64.3000     7.0000  1372.0000    83.6210     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    65.0000     9.0000   960.4000   992.9990     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    65.9000    10.0000   672.2800  4097.4300     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    66.9000    17.0000   470.5960  1985.9900     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
i41    68.6000    20.0000   329.4172  1087.0730     0.0200   -50.0000     0.0000     0.0000     0.0000     1.0000
; END EVENT: generated 8 - direct 0

; ---------------------- END FILE: total 84


</CsScore>
</CsoundSynthesizer>

